# frozen_string_literal: true

module Gitlab
  module GitalyClient
    class MercurialRepositoryService
      include Gitlab::EncodingHelper

      # 'repository' is a Mercurial subclass of Gitlab::Git::Repository
      def initialize(repository)
        @repository = repository
        @gitaly_repo = repository.gitaly_repository
        @storage = Gitlab::GitalyClient.vcs_qualified_storage(
          repository.storage, 'hg')
      end

      def config_item_bool(section, item)
        request = Hgitaly::GetConfigItemRequest.new(
          repository: @gitaly_repo,
          section: section,
          name: item,
          as_type: Hgitaly::ConfigItemType::BOOL
        )
        response = GitalyClient.call(
          @storage, :mercurial_repository_service, :get_config_item, request,
          timeout: GitalyClient.fast_timeout
        )
        response.as_bool
      end
    end
  end
end
