# frozen_string_literal: true

require "spec_helper"

# rubocop:disable RSpec/FilePath
RSpec.describe Gitlab::Git::Blame, :seed_helper do
  include Gitlab::EncodingHelper
  include RepoHelpers
  include Gitlab::Popen

  before do
    stub_const('HGITALY_TEST_REPO_PATH', 'hgitaly-repo.git')
  end

  let(:user) { build(:user) }
  let(:repository) do
    repo = Gitlab::Mercurial::HgitalyRepository.new('default',
                                                    HGITALY_TEST_REPO_PATH, '', 'group/project')
    repo.unit_tests_skip_hooks = true
    status = repo.create_repository(namespace_fs_path: "group", in_subgroup: false)
    expect(status).to be(true)

    repo.multi_action(user,
                      branch_name: 'branch/default',
                      message: "Commit 0",
                      author_email: "jdoe1@heptapod.test",
                      author_name: "John Doe1",
                      actions: [{ action: :create,
                                  file_path: 'foo',
                                  content: "foo0\n" }])
    repo
  end

  describe '#each' do
    after do
      repository.remove
    end

    it 'gets results from HGitaly' do
      # we don't need extensive testing that the results are correct, since
      # that is done in HGitaly/Gitaly comparison tests
      # THe purpose of this test is to prove that HGitaly was properly called
      commit = repository.find_branch('branch/default').dereferenced_target
      blame = Gitlab::Git::Blame.new(repository, commit.id, 'foo')
      expect(blame.lines.length).to eq(1)
      blame_line = blame.lines[0]
      expect(blame_line.commit).to eq(commit)
      expect(blame_line.lineno).to eq(1)
      expect(blame_line.oldlineno).to eq(1)
      expect(blame_line.line).to eq('foo0')
    end
  end
end
