# frozen_string_literal: true

require 'spec_helper'
require Rails.root.join('db', 'migrate', '20210527131946_force_notes_rerender.rb')

RSpec.describe ForceNotesRerender do
  let(:notes) { table(:notes) }
  let(:users) { table(:users) }
  let(:user) { users.create!(email: 'user@heptapod.test', projects_limit: 5) }

  it 'clears the rendered field' do
    # apparently the application-level list of allowed VCS types is nil in that context
    # this breaks Project creation
    allow_next_instance_of(Project) do |proj|
      allow(proj).to receive(:check_vcs_type).and_return(nil)
    end
    # quoting development/testing_guide/testing_migration_guides.html:
    #   FactoryBot should not be used to create data for migration specs
    #   because it relies on application code which can change after the migration has run
    # which does not apply for this migration, as there is no related code change, hence
    # disabling the cop is safe.
    note = create(:note_on_issue) # rubocop:disable RSpec/FactoriesInMigrationSpecs
    note.note = "## Some level 2 title"
    note.project.vcs_type = "hg_git"
    note.project.save!
    note.save!
    expected_rendering_rx = %r{<h2.*>Some level 2 title</h2>}

    note_git = create(:note_on_issue) # rubocop:disable RSpec/FactoriesInMigrationSpecs
    note_git.note = "## On a Git project"
    note_git.save!
    expected_rendering_rx_git = %r{<h2.*>On a Git project</h2>}

    Notes::RenderService.new(user).execute([note, note_git])
    expect(note.note_html).to match(expected_rendering_rx)
    expect(note_git.note_html).to match(expected_rendering_rx_git)

    expect { migrate! }.to change { notes.where(note_html: nil).count }.by(1)

    note = Note.find(note.id) # reload from DB
    expect(note.note_html).to be_nil
    # next rendering will work as expected
    Notes::RenderService.new(user).execute([note])
    expect(note.note_html).to match(expected_rendering_rx)

    # on the other hand, note_html is unchanged on Git project
    note_git = Note.find(note_git.id) # reload from DB
    expect(note_git.note_html).to match(expected_rendering_rx_git)
  end
end
