# frozen_string_literal: true

class ChangeProjectIndexOnVulnerabilityExports < ActiveRecord::Migration[6.0]
  include Gitlab::Database::MigrationHelpers

  DOWNTIME = false
  OLD_INDEX_NAME = 'index_vulnerability_exports_on_project_id_and_id'
  NEW_INDEX_NAME = 'index_vulnerability_exports_on_project_id_not_null'

  disable_ddl_transaction!

  def up
    add_concurrent_index(:vulnerability_exports, :project_id, where: 'project_id IS NOT NULL', name: NEW_INDEX_NAME)
    remove_concurrent_index_by_name(:vulnerability_exports, OLD_INDEX_NAME)
  end

  def down
    add_concurrent_index(:vulnerability_exports, [:project_id, :id], unique: true, name: OLD_INDEX_NAME)
    remove_concurrent_index_by_name(:vulnerability_exports, NEW_INDEX_NAME)
  end
end
